# TestResultCreateModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**duration_in_ms** | **int, none_type** |  | [optional] 
**step_comments** | [**[TestResultStepCommentPutModel], none_type**](TestResultStepCommentPutModel.md) |  | [optional] 
**failure_class_ids** | **[str], none_type** |  | [optional] 
**outcome** | **str, none_type** |  | [optional] 
**comment** | **str, none_type** |  | [optional] 
**links** | [**[LinkModel], none_type**](LinkModel.md) |  | [optional] 
**step_results** | [**[StepResultModel], none_type**](StepResultModel.md) |  | [optional] 
**attachments** | [**[AttachmentPutModel], none_type**](AttachmentPutModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


